@@ -443,10 +443,12 @@ bool gcpTextTool::OnFont()
 			g_object_unref((GObject*)tag);
 		}
 		pango_font_description_free(pfd);
-		if (m_Active) gtk_text_buffer_apply_tag_by_name(buf, FontName, &start, &end);
-		gcpText *text = (gcpText*)g_object_get_data(G_OBJECT(m_Active), "object");
-		text->OnChanged(buf);
-		if (gtk_text_iter_compare(&start, &end)) PushNode(text->SaveSelected());
+		if (m_Active) {
+			gtk_text_buffer_apply_tag_by_name(buf, FontName, &start, &end);
+			gcpText *text = (gcpText*)g_object_get_data(G_OBJECT(m_Active), "object");
+			text->OnChanged(buf);
+			if (gtk_text_iter_compare(&start, &end)) PushNode(text->SaveSelected());
+		}
 	}
 	gtk_widget_destroy(dialog);
 	return true;
